import { API as API$1 } from "../../../scw/api.js";
import { validatePathParam, urlParams } from "../../../helpers/marshalling.js";
import "../../../vendor/base64/index.js";
import { enrichForPagination } from "../../../scw/fetch/resource-paginator.js";
import { unmarshalListPartnersResponse, unmarshalPartner, unmarshalListPopsResponse, unmarshalPop, unmarshalListLinksResponse, unmarshalLink, marshalCreateLinkRequest, marshalUpdateLinkRequest, marshalAttachVpcRequest, marshalAttachRoutingPolicyRequest, unmarshalListRoutingPoliciesResponse, unmarshalRoutingPolicy, marshalCreateRoutingPolicyRequest, marshalUpdateRoutingPolicyRequest } from "./marshalling.gen.js";
const jsonContentHeaders = {
  "Content-Type": "application/json; charset=utf-8"
};
class API extends API$1 {
  /** Lists the available regions of the API. */
  static LOCALITIES = [
    "fr-par",
    "nl-ams",
    "pl-waw"
  ];
  pageOfListPartners = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/interlink/v1beta1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/partners`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["pop_ids", request.popIds]
      )
    },
    unmarshalListPartnersResponse
  );
  /**
   * List available partners. List all available partners. By default, the
   * partners returned in the list are ordered by name in ascending order,
   * though this can be modified via the `order_by` field.
   *
   * @param request - The request {@link ListPartnersRequest}
   * @returns A Promise of ListPartnersResponse
   */
  listPartners = (request = {}) => enrichForPagination("partners", this.pageOfListPartners, request);
  /**
   * Get a partner. Get a partner for the given partner IP. The response object
   * includes information such as the partner's name, email address and portal
   * URL.
   *
   * @param request - The request {@link GetPartnerRequest}
   * @returns A Promise of Partner
   */
  getPartner = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/interlink/v1beta1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/partners/${validatePathParam("partnerId", request.partnerId)}`
    },
    unmarshalPartner
  );
  pageOfListPops = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/interlink/v1beta1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/pops`,
      urlParams: urlParams(
        ["hosting_provider_name", request.hostingProviderName],
        ["link_bandwidth_mbps", request.linkBandwidthMbps],
        ["name", request.name],
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["partner_id", request.partnerId]
      )
    },
    unmarshalListPopsResponse
  );
  /**
   * List PoPs. List all available PoPs (locations) for a given region. By
   * default, the results are returned in ascending alphabetical order by name.
   *
   * @param request - The request {@link ListPopsRequest}
   * @returns A Promise of ListPopsResponse
   */
  listPops = (request = {}) => enrichForPagination("pops", this.pageOfListPops, request);
  /**
   * Get a PoP. Get a PoP for the given PoP ID. The response object includes the
   * PoP's name and information about its physical location.
   *
   * @param request - The request {@link GetPopRequest}
   * @returns A Promise of Pop
   */
  getPop = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/interlink/v1beta1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/pops/${validatePathParam("popId", request.popId)}`
    },
    unmarshalPop
  );
  pageOfListLinks = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/interlink/v1beta1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/links`,
      urlParams: urlParams(
        ["bandwidth_mbps", request.bandwidthMbps],
        ["bgp_v4_status", request.bgpV4Status],
        ["bgp_v6_status", request.bgpV6Status],
        ["name", request.name],
        ["order_by", request.orderBy],
        ["organization_id", request.organizationId],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["pairing_key", request.pairingKey],
        ["partner_id", request.partnerId],
        ["pop_id", request.popId],
        ["project_id", request.projectId],
        ["routing_policy_id", request.routingPolicyId],
        ["status", request.status],
        ["tags", request.tags],
        ["vpc_id", request.vpcId]
      )
    },
    unmarshalListLinksResponse
  );
  /**
   * List links. List all your links (InterLink connections). A number of
   * filters are available, including Project ID, name, tags and status.
   *
   * @param request - The request {@link ListLinksRequest}
   * @returns A Promise of ListLinksResponse
   */
  listLinks = (request = {}) => enrichForPagination("links", this.pageOfListLinks, request);
  /**
   * Get a link. Get a link (InterLink connection) for the given link ID. The
   * response object includes information about the link's various configuration
   * details.
   *
   * @param request - The request {@link GetLinkRequest}
   * @returns A Promise of Link
   */
  getLink = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/interlink/v1beta1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/links/${validatePathParam("linkId", request.linkId)}`
    },
    unmarshalLink
  );
  /**
   * Create a link. Create a link (InterLink connection) in a given PoP,
   * specifying its various configuration details. For the moment only hosted
   * links (faciliated by partners) are available, though in the future
   * dedicated and shared links will also be possible.
   *
   * @param request - The request {@link CreateLinkRequest}
   * @returns A Promise of Link
   */
  createLink = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalCreateLinkRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/interlink/v1beta1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/links`
    },
    unmarshalLink
  );
  /**
   * Update a link. Update an existing link, specified by its link ID. Only its
   * name and tags can be updated.
   *
   * @param request - The request {@link UpdateLinkRequest}
   * @returns A Promise of Link
   */
  updateLink = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalUpdateLinkRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/interlink/v1beta1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/links/${validatePathParam("linkId", request.linkId)}`
    },
    unmarshalLink
  );
  /**
   * Delete a link. Delete an existing link, specified by its link ID. Note that
   * as well as deleting the link here on the Scaleway side, it is also
   * necessary to request deletion from the partner on their side. Only when
   * this action has been carried out on both sides will the resource be
   * completely deleted.
   *
   * @param request - The request {@link DeleteLinkRequest}
   * @returns A Promise of Link
   */
  deleteLink = (request) => this.client.fetch(
    {
      method: "DELETE",
      path: `/interlink/v1beta1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/links/${validatePathParam("linkId", request.linkId)}`
    },
    unmarshalLink
  );
  /**
   * Attach a VPC. Attach a VPC to an existing link. This facilitates
   * communication between the resources in your Scaleway VPC, and your
   * on-premises infrastructure.
   *
   * @param request - The request {@link AttachVpcRequest}
   * @returns A Promise of Link
   */
  attachVpc = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalAttachVpcRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/interlink/v1beta1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/links/${validatePathParam("linkId", request.linkId)}/attach-vpc`
    },
    unmarshalLink
  );
  /**
   * Detach a VPC. Detach a VPC from an existing link.
   *
   * @param request - The request {@link DetachVpcRequest}
   * @returns A Promise of Link
   */
  detachVpc = (request) => this.client.fetch(
    {
      body: "{}",
      headers: jsonContentHeaders,
      method: "POST",
      path: `/interlink/v1beta1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/links/${validatePathParam("linkId", request.linkId)}/detach-vpc`
    },
    unmarshalLink
  );
  /**
   * Attach a routing policy. Attach a routing policy to an existing link. As
   * all routes across the link are blocked by default, you must attach a
   * routing policy to set IP prefix filters for allowed routes, facilitating
   * traffic flow.
   *
   * @param request - The request {@link AttachRoutingPolicyRequest}
   * @returns A Promise of Link
   */
  attachRoutingPolicy = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalAttachRoutingPolicyRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/interlink/v1beta1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/links/${validatePathParam("linkId", request.linkId)}/attach-routing-policy`
    },
    unmarshalLink
  );
  /**
   * Detach a routing policy. Detach a routing policy from an existing link.
   * Without a routing policy, all routes across the link are blocked by
   * default.
   *
   * @param request - The request {@link DetachRoutingPolicyRequest}
   * @returns A Promise of Link
   */
  detachRoutingPolicy = (request) => this.client.fetch(
    {
      body: "{}",
      headers: jsonContentHeaders,
      method: "POST",
      path: `/interlink/v1beta1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/links/${validatePathParam("linkId", request.linkId)}/detach-routing-policy`
    },
    unmarshalLink
  );
  /**
   * Enable route propagation. Enable all allowed prefixes (defined in a routing
   * policy) to be announced in the BGP session. This allows traffic to flow
   * between the attached VPC and the on-premises infrastructure along the
   * announced routes. Note that by default, even when route propagation is
   * enabled, all routes are blocked. It is essential to attach a routing policy
   * to define the ranges of routes to announce.
   *
   * @param request - The request {@link EnableRoutePropagationRequest}
   * @returns A Promise of Link
   */
  enableRoutePropagation = (request) => this.client.fetch(
    {
      body: "{}",
      headers: jsonContentHeaders,
      method: "POST",
      path: `/interlink/v1beta1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/links/${validatePathParam("linkId", request.linkId)}/enable-route-propagation`
    },
    unmarshalLink
  );
  /**
   * Disable route propagation. Prevent any prefixes from being announced in the
   * BGP session. Traffic will not be able to flow over the InterLink until
   * route propagation is re-enabled.
   *
   * @param request - The request {@link DisableRoutePropagationRequest}
   * @returns A Promise of Link
   */
  disableRoutePropagation = (request) => this.client.fetch(
    {
      body: "{}",
      headers: jsonContentHeaders,
      method: "POST",
      path: `/interlink/v1beta1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/links/${validatePathParam("linkId", request.linkId)}/disable-route-propagation`
    },
    unmarshalLink
  );
  pageOfListRoutingPolicies = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/interlink/v1beta1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/routing-policies`,
      urlParams: urlParams(
        ["name", request.name],
        ["order_by", request.orderBy],
        ["organization_id", request.organizationId],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_id", request.projectId],
        ["tags", request.tags]
      )
    },
    unmarshalListRoutingPoliciesResponse
  );
  /**
   * List routing policies. List all routing policies in a given region. A
   * routing policy can be attached to one or multiple links (InterLink
   * connections).
   *
   * @param request - The request {@link ListRoutingPoliciesRequest}
   * @returns A Promise of ListRoutingPoliciesResponse
   */
  listRoutingPolicies = (request = {}) => enrichForPagination(
    "routingPolicies",
    this.pageOfListRoutingPolicies,
    request
  );
  /**
   * Get routing policy. Get a routing policy for the given routing policy ID.
   * The response object gives information including the policy's name, tags and
   * prefix filters.
   *
   * @param request - The request {@link GetRoutingPolicyRequest}
   * @returns A Promise of RoutingPolicy
   */
  getRoutingPolicy = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/interlink/v1beta1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/routing-policies/${validatePathParam("routingPolicyId", request.routingPolicyId)}`
    },
    unmarshalRoutingPolicy
  );
  /**
   * Create a routing policy. Create a routing policy. Routing policies allow
   * you to set IP prefix filters to define the incoming route announcements to
   * accept from the peer, and the outgoing routes to announce to the peer.
   *
   * @param request - The request {@link CreateRoutingPolicyRequest}
   * @returns A Promise of RoutingPolicy
   */
  createRoutingPolicy = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalCreateRoutingPolicyRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/interlink/v1beta1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/routing-policies`
    },
    unmarshalRoutingPolicy
  );
  /**
   * Update a routing policy. Update an existing routing policy, specified by
   * its routing policy ID. Its name, tags and incoming/outgoing prefix filters
   * can be updated.
   *
   * @param request - The request {@link UpdateRoutingPolicyRequest}
   * @returns A Promise of RoutingPolicy
   */
  updateRoutingPolicy = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalUpdateRoutingPolicyRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/interlink/v1beta1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/routing-policies/${validatePathParam("routingPolicyId", request.routingPolicyId)}`
    },
    unmarshalRoutingPolicy
  );
  /**
   * Delete a routing policy. Delete an existing routing policy, specified by
   * its routing policy ID.
   *
   * @param request - The request {@link DeleteRoutingPolicyRequest}
   */
  deleteRoutingPolicy = (request) => this.client.fetch({
    method: "DELETE",
    path: `/interlink/v1beta1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/routing-policies/${validatePathParam("routingPolicyId", request.routingPolicyId)}`
  });
}
export {
  API
};
