import { API as API$1 } from "../../../scw/api.js";
import { validatePathParam, urlParams } from "../../../helpers/marshalling.js";
import "../../../vendor/base64/index.js";
import { enrichForPagination } from "../../../scw/fetch/resource-paginator.js";
import { marshalCreateKeyRequest, unmarshalKey, marshalUpdateKeyRequest, unmarshalListKeysResponse, marshalGenerateDataKeyRequest, unmarshalDataKey, marshalEncryptRequest, unmarshalEncryptResponse, marshalDecryptRequest, unmarshalDecryptResponse, marshalImportKeyMaterialRequest } from "./marshalling.gen.js";
const jsonContentHeaders = {
  "Content-Type": "application/json; charset=utf-8"
};
class API extends API$1 {
  /** Lists the available regions of the API. */
  static LOCALITIES = [
    "fr-par",
    "nl-ams",
    "pl-waw"
  ];
  /**
   * Create a key. Create a key in a given region specified by the `region`
   * parameter. Keys only support symmetric encryption. You can use keys to
   * encrypt or decrypt arbitrary payloads, or to generate data encryption keys.
   * **Data encryption keys are not stored in Key Manager**.
   *
   * @param request - The request {@link CreateKeyRequest}
   * @returns A Promise of Key
   */
  createKey = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalCreateKeyRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/key-manager/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/keys`
    },
    unmarshalKey
  );
  /**
   * Get key metadata. Retrieve metadata for a specified key using the `region`
   * and `key_id` parameters.
   *
   * @param request - The request {@link GetKeyRequest}
   * @returns A Promise of Key
   */
  getKey = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/key-manager/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/keys/${validatePathParam("keyId", request.keyId)}`
    },
    unmarshalKey
  );
  /**
   * Update a key. Modify a key's metadata including name, description and tags,
   * specified by the `key_id` and `region` parameters.
   *
   * @param request - The request {@link UpdateKeyRequest}
   * @returns A Promise of Key
   */
  updateKey = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalUpdateKeyRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/key-manager/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/keys/${validatePathParam("keyId", request.keyId)}`
    },
    unmarshalKey
  );
  /**
   * Delete a key. Permanently delete a key specified by the `region` and
   * `key_id` parameters. This action is irreversible. Any data encrypted with
   * this key, including data encryption keys, will no longer be decipherable.
   *
   * @param request - The request {@link DeleteKeyRequest}
   */
  deleteKey = (request) => this.client.fetch({
    method: "DELETE",
    path: `/key-manager/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/keys/${validatePathParam("keyId", request.keyId)}`
  });
  /**
   * Rotate a key. Generate a new version of an existing key with new key
   * material. Previous key versions remain usable to decrypt previously
   * encrypted data, but the key's new version will be used for subsequent
   * encryption operations and data key generation.
   *
   * @param request - The request {@link RotateKeyRequest}
   * @returns A Promise of Key
   */
  rotateKey = (request) => this.client.fetch(
    {
      body: "{}",
      headers: jsonContentHeaders,
      method: "POST",
      path: `/key-manager/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/keys/${validatePathParam("keyId", request.keyId)}/rotate`
    },
    unmarshalKey
  );
  /**
   * Apply key protection. Apply protection to a given key specified by the
   * `key_id` parameter. Applying key protection means that your key can be used
   * and modified, but it cannot be deleted.
   *
   * @param request - The request {@link ProtectKeyRequest}
   * @returns A Promise of Key
   */
  protectKey = (request) => this.client.fetch(
    {
      body: "{}",
      headers: jsonContentHeaders,
      method: "POST",
      path: `/key-manager/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/keys/${validatePathParam("keyId", request.keyId)}/protect`
    },
    unmarshalKey
  );
  /**
   * Remove key protection. Remove key protection from a given key specified by
   * the `key_id` parameter. Removing key protection means that your key can be
   * deleted anytime.
   *
   * @param request - The request {@link UnprotectKeyRequest}
   * @returns A Promise of Key
   */
  unprotectKey = (request) => this.client.fetch(
    {
      body: "{}",
      headers: jsonContentHeaders,
      method: "POST",
      path: `/key-manager/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/keys/${validatePathParam("keyId", request.keyId)}/unprotect`
    },
    unmarshalKey
  );
  /**
   * Enable key. Enable a given key to be used for cryptographic operations.
   * Enabling a key allows you to make a disabled key usable again. You must
   * specify the `region` and `key_id` parameters.
   *
   * @param request - The request {@link EnableKeyRequest}
   * @returns A Promise of Key
   */
  enableKey = (request) => this.client.fetch(
    {
      body: "{}",
      headers: jsonContentHeaders,
      method: "POST",
      path: `/key-manager/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/keys/${validatePathParam("keyId", request.keyId)}/enable`
    },
    unmarshalKey
  );
  /**
   * Disable key. Disable a given key, preventing it to be used for
   * cryptographic operations. Disabling a key renders it unusable. You must
   * specify the `region` and `key_id` parameters.
   *
   * @param request - The request {@link DisableKeyRequest}
   * @returns A Promise of Key
   */
  disableKey = (request) => this.client.fetch(
    {
      body: "{}",
      headers: jsonContentHeaders,
      method: "POST",
      path: `/key-manager/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/keys/${validatePathParam("keyId", request.keyId)}/disable`
    },
    unmarshalKey
  );
  pageOfListKeys = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/key-manager/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/keys`,
      urlParams: urlParams(
        ["name", request.name],
        ["order_by", request.orderBy],
        ["organization_id", request.organizationId],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_id", request.projectId],
        ["tags", request.tags]
      )
    },
    unmarshalListKeysResponse
  );
  /**
   * List keys. Retrieve a list of keys across all Projects in an Organization
   * or within a specific Project. You must specify the `region`, and either the
   * `organization_id` or the `project_id`.
   *
   * @param request - The request {@link ListKeysRequest}
   * @returns A Promise of ListKeysResponse
   */
  listKeys = (request = {}) => enrichForPagination("keys", this.pageOfListKeys, request);
  /**
   * Create a data encryption key. Create a new data encryption key for
   * cryptographic operations outside of Key Manager. The data encryption key is
   * encrypted and must be decrypted using the key you have created in Key
   * Manager.
   *
   * The data encryption key is returned in plaintext and ciphertext but it
   * should only be stored in its encrypted form (ciphertext). Key Manager does
   * not store your data encryption key. To retrieve your key's plaintext, use
   * the `Decrypt` method with your key's ID and ciphertext.
   *
   * @param request - The request {@link GenerateDataKeyRequest}
   * @returns A Promise of DataKey
   */
  generateDataKey = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalGenerateDataKeyRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/key-manager/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/keys/${validatePathParam("keyId", request.keyId)}/generate-data-key`
    },
    unmarshalDataKey
  );
  /**
   * Encrypt a payload. Encrypt a payload using an existing key, specified by
   * the `key_id` parameter. Only keys with a usage set to
   * `symmetric_encryption` are supported by this method. The maximum payload
   * size that can be encrypted is 64 KB of plaintext.
   *
   * @param request - The request {@link EncryptRequest}
   * @returns A Promise of EncryptResponse
   */
  encrypt = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalEncryptRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/key-manager/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/keys/${validatePathParam("keyId", request.keyId)}/encrypt`
    },
    unmarshalEncryptResponse
  );
  /**
   * Decrypt an encrypted payload. Decrypt an encrypted payload using an
   * existing key, specified by the `key_id` parameter. The maximum payload size
   * that can be decrypted is equivalent to the encrypted output of 64 KB of
   * data (around 131 KB).
   *
   * @param request - The request {@link DecryptRequest}
   * @returns A Promise of DecryptResponse
   */
  decrypt = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalDecryptRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/key-manager/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/keys/${validatePathParam("keyId", request.keyId)}/decrypt`
    },
    unmarshalDecryptResponse
  );
  /**
   * Import key material. Import externally generated key material into Key
   * Manager to derive a new cryptographic key. The key's origin must be
   * `external`.
   *
   * @param request - The request {@link ImportKeyMaterialRequest}
   * @returns A Promise of Key
   */
  importKeyMaterial = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalImportKeyMaterialRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/key-manager/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/keys/${validatePathParam("keyId", request.keyId)}/import-key-material`
    },
    unmarshalKey
  );
  /**
   * Delete key material. Delete previously imported key material. This renders
   * the associated cryptographic key unusable for any operation. The key's
   * origin must be `external`.
   *
   * @param request - The request {@link DeleteKeyMaterialRequest}
   */
  deleteKeyMaterial = (request) => this.client.fetch({
    body: "{}",
    headers: jsonContentHeaders,
    method: "POST",
    path: `/key-manager/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/keys/${validatePathParam("keyId", request.keyId)}/delete-key-material`
  });
}
export {
  API
};
